pyspex
======

Python package pyspex contains software to access SPEXone data.
This package contains software scripts and classes to:
* Read data packages from the SPEXone instrument and write the data in 
Level-1A format.
* Read Level-0 data from the SPEXone after integration on the PACE platform
and write the data in Level-1A in-flight science and calibration products
(not yet available).
* Handle SPEXone binning tables (read, write, visualize).
And provides the format definitions of the SPEXone level-1 products (A, B and C).


For more information on PACE mission visit:
* https://pace.gsfc.nasa.gov
* https://pace.oceansciences.org/mission.htm

For more information on SPEXone instrument visit:
* https://www.sron.nl/earth-instrument-development/spex/spexone
* https://pace.oceansciences.org/spexone.htm


Installation
------------
Installation instructions are provided in the INSTALL file.

We installed the software successfully on Linux, MaxOS and Windows.


Reporting bugs
--------------
email r.m.van.hees[at]sron.nl
